# PyLangGetter
Tiny utility to help you download Dofus Retro Lang files.

## Usage
`python PyLangGetter.py` to get all lang files in all language \
`python PyLangGetter.py fr` to get lang files in **fr** language \
`python PylangGetter.py it de` to get lang files in **it** and **de** langage \
Available language option : `fr, de, en, it, es, pt, nl`